@@ -91,7 +91,7 @@ class Exceptions:
 
 class AccessAnalyzerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html)
     """
 
@@ -104,13 +104,13 @@ class AccessAnalyzerClient(BaseClient):
         """
 
     def apply_archive_rule(
-        self, *, analyzerArn: str, ruleName: str, clientToken: str = None
+        self, *, analyzerArn: str, ruleName: str, clientToken: str = ...
     ) -> None:
         """
         Retroactively applies the archive rule to existing findings that meet the
         archive rule criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#apply_archive_rule)
         """
 
@@ -118,7 +118,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#can_paginate)
         """
 
@@ -126,7 +126,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Cancels the requested policy generation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#cancel_policy_generation)
         """
 
@@ -135,13 +135,13 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerArn: str,
         configurations: Mapping[str, "ConfigurationTypeDef"],
-        clientToken: str = None
+        clientToken: str = ...
     ) -> CreateAccessPreviewResponseTypeDef:
         """
         Creates an access preview that allows you to preview IAM Access Analyzer
         findings for your resource before deploying resource permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_access_preview)
         """
 
@@ -150,14 +150,14 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerName: str,
         type: TypeType,
-        archiveRules: Sequence["InlineArchiveRuleTypeDef"] = None,
-        clientToken: str = None,
-        tags: Mapping[str, str] = None
+        archiveRules: Sequence["InlineArchiveRuleTypeDef"] = ...,
+        clientToken: str = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateAnalyzerResponseTypeDef:
         """
         Creates an analyzer for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_analyzer)
         """
 
@@ -167,44 +167,44 @@ class AccessAnalyzerClient(BaseClient):
         analyzerName: str,
         filter: Mapping[str, "CriterionTypeDef"],
         ruleName: str,
-        clientToken: str = None
+        clientToken: str = ...
     ) -> None:
         """
         Creates an archive rule for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_archive_rule)
         """
 
-    def delete_analyzer(self, *, analyzerName: str, clientToken: str = None) -> None:
+    def delete_analyzer(self, *, analyzerName: str, clientToken: str = ...) -> None:
         """
         Deletes the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_analyzer)
         """
 
     def delete_archive_rule(
-        self, *, analyzerName: str, ruleName: str, clientToken: str = None
+        self, *, analyzerName: str, ruleName: str, clientToken: str = ...
     ) -> None:
         """
         Deletes the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_archive_rule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#generate_presigned_url)
         """
 
@@ -214,7 +214,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an access preview for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_access_preview)
         """
 
@@ -224,7 +224,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about a resource that was analyzed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzed_resource)
         """
 
@@ -232,7 +232,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzer)
         """
 
@@ -242,7 +242,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_archive_rule)
         """
 
@@ -250,7 +250,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified finding.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_finding)
         """
 
@@ -258,13 +258,13 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         jobId: str,
-        includeResourcePlaceholders: bool = None,
-        includeServiceLevelTemplate: bool = None
+        includeResourcePlaceholders: bool = ...,
+        includeServiceLevelTemplate: bool = ...
     ) -> GetGeneratedPolicyResponseTypeDef:
         """
         Retrieves the policy that was generated using `StartPolicyGeneration` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_generated_policy)
         """
 
@@ -273,25 +273,25 @@ class AccessAnalyzerClient(BaseClient):
         *,
         accessPreviewId: str,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = None,
-        maxResults: int = None,
-        nextToken: str = None
+        filter: Mapping[str, "CriterionTypeDef"] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListAccessPreviewFindingsResponseTypeDef:
         """
         Retrieves a list of access preview findings generated by the specified access
         preview.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_preview_findings)
         """
 
     def list_access_previews(
-        self, *, analyzerArn: str, maxResults: int = None, nextToken: str = None
+        self, *, analyzerArn: str, maxResults: int = ..., nextToken: str = ...
     ) -> ListAccessPreviewsResponseTypeDef:
         """
         Retrieves a list of access previews for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_previews)
         """
 
@@ -299,35 +299,35 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        maxResults: int = None,
-        nextToken: str = None,
-        resourceType: ResourceTypeType = None
+        maxResults: int = ...,
+        nextToken: str = ...,
+        resourceType: ResourceTypeType = ...
     ) -> ListAnalyzedResourcesResponseTypeDef:
         """
         Retrieves a list of resources of the specified type that have been analyzed by
         the specified analyzer..
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzed_resources)
         """
 
     def list_analyzers(
-        self, *, maxResults: int = None, nextToken: str = None, type: TypeType = None
+        self, *, maxResults: int = ..., nextToken: str = ..., type: TypeType = ...
     ) -> ListAnalyzersResponseTypeDef:
         """
         Retrieves a list of analyzers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzers)
         """
 
     def list_archive_rules(
-        self, *, analyzerName: str, maxResults: int = None, nextToken: str = None
+        self, *, analyzerName: str, maxResults: int = ..., nextToken: str = ...
     ) -> ListArchiveRulesResponseTypeDef:
         """
         Retrieves a list of archive rules created for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_archive_rules)
         """
 
@@ -335,25 +335,25 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = None,
-        maxResults: int = None,
-        nextToken: str = None,
-        sort: "SortCriteriaTypeDef" = None
+        filter: Mapping[str, "CriterionTypeDef"] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        sort: "SortCriteriaTypeDef" = ...
     ) -> ListFindingsResponseTypeDef:
         """
         Retrieves a list of findings generated by the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_findings)
         """
 
     def list_policy_generations(
-        self, *, maxResults: int = None, nextToken: str = None, principalArn: str = None
+        self, *, maxResults: int = ..., nextToken: str = ..., principalArn: str = ...
     ) -> ListPolicyGenerationsResponseTypeDef:
         """
         Lists all of the policy generations requested in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_policy_generations)
         """
 
@@ -361,7 +361,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of tags applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_tags_for_resource)
         """
 
@@ -369,13 +369,13 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         policyGenerationDetails: "PolicyGenerationDetailsTypeDef",
-        clientToken: str = None,
-        cloudTrailDetails: "CloudTrailDetailsTypeDef" = None
+        clientToken: str = ...,
+        cloudTrailDetails: "CloudTrailDetailsTypeDef" = ...
     ) -> StartPolicyGenerationResponseTypeDef:
         """
         Starts the policy generation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_policy_generation)
         """
 
@@ -383,7 +383,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Immediately starts a scan of the policies applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_resource_scan)
         """
 
@@ -391,7 +391,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Adds a tag to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#tag_resource)
         """
 
@@ -399,7 +399,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Removes a tag from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#untag_resource)
         """
 
@@ -409,12 +409,12 @@ class AccessAnalyzerClient(BaseClient):
         analyzerName: str,
         filter: Mapping[str, "CriterionTypeDef"],
         ruleName: str,
-        clientToken: str = None
+        clientToken: str = ...
     ) -> None:
         """
         Updates the criteria and values for the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_archive_rule)
         """
 
@@ -423,14 +423,14 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerArn: str,
         status: FindingStatusUpdateType,
-        clientToken: str = None,
-        ids: Sequence[str] = None,
-        resourceArn: str = None
+        clientToken: str = ...,
+        ids: Sequence[str] = ...,
+        resourceArn: str = ...
     ) -> None:
         """
         Updates the status for the specified findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_findings)
         """
 
@@ -439,14 +439,14 @@ class AccessAnalyzerClient(BaseClient):
         *,
         policyDocument: str,
         policyType: PolicyTypeType,
-        locale: LocaleType = None,
-        maxResults: int = None,
-        nextToken: str = None
+        locale: LocaleType = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ValidatePolicyResponseTypeDef:
         """
         Requests the validation of a policy and returns a list of findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#validate_policy)
         """
 
@@ -455,7 +455,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
@@ -464,7 +464,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
@@ -473,14 +473,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
@@ -489,14 +489,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
@@ -505,13 +505,13 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_policy_generations"]
     ) -> ListPolicyGenerationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
