@@ -47,6 +47,7 @@ __all__ = (
     "ValidatePolicyFindingTypeType",
     "ValidatePolicyPaginatorName",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -379,10 +380,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -390,3 +393,13 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_access_preview_findings",
+    "list_access_previews",
+    "list_analyzed_resources",
+    "list_analyzers",
+    "list_archive_rules",
+    "list_findings",
+    "list_policy_generations",
+    "validate_policy",
+]
